PAWpySeed: pawpyseed.core.noncollinear.NCLWavefunction Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
pawpyseed.core.noncollinear.NCLWavefunction Class Reference
Inheritance diagram for pawpyseed.core.noncollinear.NCLWavefunction:
[legend]
Collaboration diagram for pawpyseed.core.noncollinear.NCLWavefunction:
[legend]

## Public Member Functions
def | __init__ (self, struct, pwf, cr, outcar, setup_projectors=True)
def | write_state_realspace (self, b, k, s, fileprefix="", dim=None)
Public Member Functions inherited from pawpyseed.core.wavefunction.Wavefunction
def | __init__ (self, struct, pwf, cr, dim, setup_projectors=False)
def | desymmetrized_copy (self, allkpts=None, weights=None)
def | check_c_projectors (self)
def | get_state_realspace (self, b, k, s, dim=None)
def | get_realspace_density (self, dim=None)
def | write_state_realspace (self, b, k, s, fileprefix="", dim=None, scale=1)
def | write_density_realspace (self, filename="PYAECCAR", dim=None, scale=1)
def | get_nosym_kpoints (self, init_kpts=None, symprec=1e-5, gen_trsym=True, fil_trsym=True)
def | get_kpt_mapping (self, allkpts, symprec=1e-5, gen_trsym=True)

## Static Public Member Functions
def | from_files (struct="CONTCAR", pwf="WAVECAR", cr="POTCAR", vr="vasprun.xml", outcar="OUTCAR", setup_projectors=True)
def | from_directory (path, setup_projectors=True)
Static Public Member Functions inherited from pawpyseed.core.wavefunction.Wavefunction
def | from_files (struct="CONTCAR", wavecar="WAVECAR", cr="POTCAR", vr="vasprun.xml", outcar="OUTCAR", setup_projectors=False)
def | from_directory (path, setup_projectors=False)
def | from_atomate_directory (path, setup_projectors=False)

## Public Attributes
| structure
| pwf
| cr
| dim
| projector_owner
| projector_list
| nums
| coords
| nband
| nwk
| nspin
| num_proj_els
Public Attributes inherited from pawpyseed.core.wavefunction.Wavefunction
| band_props
| structure
| cr
| dim
| num_sites
| num_elems

## Constructor & Destructor Documentation

def pawpyseed.core.noncollinear.NCLWavefunction.__init__ | ( |  | self,
|  |  | struct,
|  |  | pwf,
|  |  | cr,
|  |  | outcar,
|  |  | setup_projectors = `True`
| ) |  |

    Arguments:
        struct (pymatgen.core.Structure): structure that the wavefunction describes
        pwf (PseudoWavefunction): Pseudowavefunction componenet
        cr (CoreRegion): Contains the pseudopotentials, with projectors and
    partials waves, for the structure
        outcar (pymatgen.io.vasp.outputs.Outcar): Outcar object for reading ngf
    Returns:
        Wavefunction object

## Member Function Documentation

def pawpyseed.core.noncollinear.NCLWavefunction.from_directory | ( |  | path,
|  |  | setup_projectors = `True`
| ) |  |
| static

    Assumes VASP output has the default filenames and is located
    in the directory specificed by path.

def pawpyseed.core.noncollinear.NCLWavefunction.from_files | ( |  | struct = `"CONTCAR"`,
|  |  | pwf = `"WAVECAR"`,
|  |  | cr = `"POTCAR"`,
|  |  | vr = `"vasprun.xml"`,
|  |  | outcar = `"OUTCAR"`,
|  |  | setup_projectors = `True`
| ) |  |
| static

    Construct a Wavefunction object from file paths.
    Arguments:
        struct (str): VASP POSCAR or CONTCAR file path
        pwf (str): VASP WAVECAR file path
        vr (str): VASP vasprun file path
    Returns:
        Wavefunction object

def pawpyseed.core.noncollinear.NCLWavefunction.write_state_realspace | ( |  | self,
|  |  | b,
|  |  | k,
|  |  | s,
|  |  | fileprefix = `""`,
|  |  | dim = `None`
| ) |  |

    Writes the real and imaginary parts of a given band to two files,
    prefixed by fileprefix

    Args:
        b (int): band number (0-indexed!)
        k (int): kpoint number (0-indexed!)
        s (int): spin number (0-indexed!)
        dim (numpy array of 3 ints): dimensions of the FFT grid
        fileprefix (string, optional): first part of the file name
    Returns:
        None
        The wavefunction is written with z the slow index.

## Member Data Documentation

pawpyseed.core.noncollinear.NCLWavefunction.coords

pawpyseed.core.noncollinear.NCLWavefunction.cr

pawpyseed.core.noncollinear.NCLWavefunction.dim

pawpyseed.core.noncollinear.NCLWavefunction.nband

pawpyseed.core.noncollinear.NCLWavefunction.nspin

pawpyseed.core.noncollinear.NCLWavefunction.num_proj_els

pawpyseed.core.noncollinear.NCLWavefunction.nums

pawpyseed.core.noncollinear.NCLWavefunction.nwk

pawpyseed.core.noncollinear.NCLWavefunction.projector_list

pawpyseed.core.noncollinear.NCLWavefunction.projector_owner

pawpyseed.core.noncollinear.NCLWavefunction.pwf

pawpyseed.core.noncollinear.NCLWavefunction.structure

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/noncollinear.py